@@ -314,7 +314,7 @@ class LoadMaster(HttpClient):
 
         return virtual_services
 
-    def build_virtual_service(self, service, response):
+    def build_virtual_service(self, service, response=None):
         """Create a VirtualService instance with populated with API parameters
 
         This does not include potentially attached real servers
@@ -326,13 +326,15 @@ class LoadMaster(HttpClient):
         will nullify the extra listvs calls.
         :return: VirtualService object with populated attributes
         """
-        asfdsfda = service.get('MasterVSID')
         is_sub_vs = True if int(service.get('MasterVSID', 0)) != 0 else False
         if is_sub_vs:
             # Add lb properties to the sub vs
-            #response = self._get("/showvs", {"vs": service.get('MasterVSID')})
-            #parent_vs_data = get_data(response)
-            subvs_lb_props = get_sub_vs_list_from_data(response)[1]
+            if response is None:
+                response = self._get("/showvs", {"vs": service.get('MasterVSID')})
+                parent_vs_data = get_data(response)
+            else:
+                parent_vs_data = response
+            subvs_lb_props = get_sub_vs_list_from_data(parent_vs_data)[1]
             virt_serv = VirtualService(self.access_info, service.get('Index'),
                                        is_sub_vs=True)
             virt_serv.subvs_data = subvs_lb_props[service.get('Index')]
