@@ -1,6 +1,7 @@
 from nose.tools import (
     assert_equal, assert_raises, assert_true,
-    assert_is_none, assert_not_in)
+    assert_is_none, assert_not_in, assert_greater, assert_less,
+    assert_greater_equal, assert_less_equal, assert_not_equal, assert_false)
 
 # handle py3 and py2 cases:
 try:
@@ -349,3 +350,29 @@ class TestLmApiWrapperCalls:
         self.lm.new_user_cert(user)
         params = {'user': user}
         self.lm._get.assert_called_with('/usernewcert', params)
+
+    def test_operator_overloads(self):
+        lm1 = LoadMaster("1.1.1.1", cert="sdf")
+        lm2 = LoadMaster("1.1.1.2", cert="sdff")
+        lm1.version = "7.1.34.3"
+        lm2.version = "7.1.34.3"
+        assert_equal(lm1, lm2)
+        assert_less_equal(lm1, lm2)
+        assert_greater_equal(lm1, lm2)
+        lm2.version = "7.1.35"
+        assert_greater(lm2, lm1)
+        assert_greater_equal(lm2, lm1)
+        assert_less(lm1, lm2)
+        assert_less_equal(lm1, lm2)
+        assert_not_equal(lm1, lm2)
+
+    def test_operator_overloads_fail_case(self):
+        lm1 = LoadMaster("1.1.1.1", cert="sdf")
+        lm2 = object()
+        lm1.version = "7.1.34.3"
+        assert_false(lm1 == lm2)
+        assert_true(lm1 != lm2)
+        assert_false(lm1 < lm2)
+        assert_false(lm1 > lm2)
+        assert_false(lm1 <= lm2)
+        assert_false(lm1 >= lm2)
